@@ -3,7 +3,7 @@ from typing import List
 import pandas as pd
 from pandas.core.dtypes.common import is_datetime64_ns_dtype
 
-from model_quality_report.splitters.base import SplitterBase, Splits, Split
+from model_quality_report.splitters.base import SplitterBase, Split, SplitGenerator
 
 
 class ByFrequency(SplitterBase):
@@ -36,14 +36,18 @@ class ByFrequency(SplitterBase):
 
     lbl_date_column_name = "date_column_name"
     lbl_start_split_date = "start_split_date"
+    lbl_end_split_date = "end_split_date"
     lbl_frequency = "frequency"
 
-    def __init__(self, start_split_date: pd.Timestamp, date_column_name: str, frequency: str) -> None:
+    def __init__(
+        self, start_split_date: pd.Timestamp, date_column_name: str, frequency: str, end_split_date: pd.Timestamp = None
+    ) -> None:
         self.start_split_date = start_split_date
+        self.end_split_date = end_split_date
         self.date_column_name = date_column_name
         self.frequency = frequency
 
-    def split(self, X: pd.DataFrame, y: pd.Series) -> Splits:
+    def split(self, X: pd.DataFrame, y: pd.Series) -> SplitGenerator:
         """
         Given df with features X, target series y and test config, data are split into test and training data
         taking data from last time_delta long period as test data and the rest as training data.
@@ -52,7 +56,8 @@ class ByFrequency(SplitterBase):
         :param y:
         :return: list of (X_train, X_test, y_train, y_test)
         """
-        return [self._split_date_data(X=X, y=y, split_date=split_date) for split_date in self._get_all_split_dates(X=X)]
+        for split_date in self._get_all_split_dates(X=X):
+            yield self._split_date_data(X=X, y=y, split_date=split_date)
 
     def _split_date_data(self, X: pd.DataFrame, y: pd.Series, split_date: pd.Timestamp) -> Split:
         X_train = X.loc[X[self.date_column_name] < split_date]
@@ -73,16 +78,30 @@ class ByFrequency(SplitterBase):
         try:
             if X[self.date_column_name].max() < self.start_split_date:
                 validation_error.append(
-                    "start split date {} is larger than max date {}".format(
-                        self.start_split_date, X[self.date_column_name].max()
-                    )
+                    f"start split date {self.start_split_date} is larger "
+                    f"than max date {X[self.date_column_name].max()}"
                 )
             if X[self.date_column_name].min() > self.start_split_date:
                 validation_error.append(
-                    "start split date {} is smaller than min date {}".format(
-                        self.start_split_date, X[self.date_column_name].min()
-                    )
+                    f"start split date {self.start_split_date} is smaller "
+                    f"than min date {X[self.date_column_name].min()}"
                 )
+            if self.end_split_date is not None:
+                if self.start_split_date >= self.end_split_date:
+                    validation_error.append(
+                        f"start split date {self.start_split_date} is not smaller "
+                        f"than end split date {self.end_split_date}"
+                    )
+                if X[self.date_column_name].max() < self.end_split_date:
+                    validation_error.append(
+                        f"end split date {self.end_split_date} is larger "
+                        f"than max date {X[self.date_column_name].max()}"
+                    )
+                if X[self.date_column_name].min() > self.end_split_date:
+                    validation_error.append(
+                        f"end split date {self.end_split_date} is smaller "
+                        f"than min date {X[self.date_column_name].min()}"
+                    )
         except TypeError as e:
             validation_error.append(str(e))
 
@@ -102,6 +121,7 @@ class ByFrequency(SplitterBase):
     def get_parameters(self) -> dict:
         return {
             self.lbl_start_split_date: self.start_split_date,
+            self.lbl_end_split_date: self.end_split_date,
             self.lbl_date_column_name: self.date_column_name,
             self.lbl_frequency: self.frequency,
         }
@@ -109,6 +129,6 @@ class ByFrequency(SplitterBase):
     def _get_all_split_dates(self, X: pd.DataFrame) -> pd.DatetimeIndex:
         return pd.date_range(
             start=self.start_split_date,
-            end=X[self.date_column_name].max(),
+            end=X[self.date_column_name].max() if self.end_split_date is None else self.end_split_date,
             freq=self.frequency,
         )
