@@ -30,11 +30,7 @@ class Test2DQualityReport(unittest.TestCase):
         dates = pd.date_range("2019-01-01", periods=7)
         self.index = pd.DatetimeIndex(dates, name=self.lbl_date)
         self.X = pd.DataFrame(
-            {
-                "a": [1, 2, 4, 5, 7, 20, 6],
-                "b": [3, 5, 7, 10, 15, 30, 22],
-                "date": dates,
-            },
+            {"a": [1, 2, 4, 5, 7, 20, 6], "b": [3, 5, 7, 10, 15, 30, 22], "date": dates},
             index=self.index,
         )
         self.y = pd.Series([3, 6, 8, 10, 12, 30, 23], index=self.index)
@@ -61,8 +57,8 @@ class Test2DQualityReport(unittest.TestCase):
 
     def test_fit_does_not_create_error_when_proper_model_is_provided(self):
         quality_report = CrossValidationTimeSeriesQualityReport(self.model, self.splitter)
-        (X_train, X_test, y_train, y_test,) = quality_report._split_data_for_quality_assessment(
-            self.X, self.y
+        (X_train, X_test, y_train, y_test,) = list(
+            quality_report._split_data_for_quality_assessment(self.X, self.y)
         )[0]
         quality_report._fit(X_train, y_train)
 
@@ -70,9 +66,8 @@ class Test2DQualityReport(unittest.TestCase):
 
     def test_quality_report_contains_error_if_fit_attribute_is_not_present(self):
         quality_report = CrossValidationTimeSeriesQualityReport("no_model_but_string", self.splitter)
-        (X_train, X_test, y_train, y_test,) = quality_report._split_data_for_quality_assessment(
-            self.X,
-            self.y,
+        (X_train, X_test, y_train, y_test,) = list(
+            quality_report._split_data_for_quality_assessment(self.X, self.y)
         )[0]
         quality_report._fit(X_train, y_train)
 
@@ -81,9 +76,8 @@ class Test2DQualityReport(unittest.TestCase):
 
     def test_predict_does_not_create_error_when_proper_model_is_provided(self):
         quality_report = CrossValidationTimeSeriesQualityReport(self.model, self.splitter)
-        (X_train, X_test, y_train, y_test,) = quality_report._split_data_for_quality_assessment(
-            self.X,
-            self.y,
+        (X_train, X_test, y_train, y_test,) = list(
+            quality_report._split_data_for_quality_assessment(self.X, self.y)
         )[0]
         quality_report._fit(X_train, y_train)
         prediction_result = quality_report._predict(X_test)
@@ -110,28 +104,17 @@ class Test2DQualityReport(unittest.TestCase):
         self.assertTrue(quality_report._errors.is_empty())
         self.assertTrue(isinstance(result, dict))
         self.assertEqual(
-            [
-                CrossValidationTimeSeriesQualityReport.lbl_metrics,
-                CrossValidationTimeSeriesQualityReport.lbl_data,
-            ],
+            [CrossValidationTimeSeriesQualityReport.lbl_metrics, CrossValidationTimeSeriesQualityReport.lbl_data],
             list(result.keys()),
         )
         self.assertTrue(isinstance(result[CrossValidationTimeSeriesQualityReport.lbl_metrics], pd.DataFrame))
-        self.assertTrue(
-            isinstance(
-                result.get(CrossValidationTimeSeriesQualityReport.lbl_data),
-                pd.DataFrame,
-            )
-        )
+        self.assertTrue(isinstance(result.get(CrossValidationTimeSeriesQualityReport.lbl_data), pd.DataFrame))
 
-    def test_quality_report_contains_error_if_fit_and_predict_attribute_are_not_present(
-        self,
-    ):
+    def test_quality_report_contains_error_if_fit_and_predict_attribute_are_not_present(self):
         for model in [None, "no_model_but_string"]:
             quality_report = CrossValidationTimeSeriesQualityReport(model, self.splitter)
-            (X_train, X_test, y_train, y_test,) = quality_report._split_data_for_quality_assessment(
-                self.X,
-                self.y,
+            (X_train, X_test, y_train, y_test,) = list(
+                quality_report._split_data_for_quality_assessment(self.X, self.y)
             )[0]
             quality_report._fit(X_train, y_train)
             prediction_result = quality_report._predict(X_test)
@@ -159,19 +142,11 @@ class Test2DQualityReport(unittest.TestCase):
 
         self.assertTrue(isinstance(result, dict))
         self.assertEqual(
-            [
-                CrossValidationTimeSeriesQualityReport.lbl_metrics,
-                CrossValidationTimeSeriesQualityReport.lbl_data,
-            ],
+            [CrossValidationTimeSeriesQualityReport.lbl_metrics, CrossValidationTimeSeriesQualityReport.lbl_data],
             list(result.keys()),
         )
         self.assertTrue(isinstance(result[CrossValidationTimeSeriesQualityReport.lbl_metrics], pd.DataFrame))
-        self.assertTrue(
-            isinstance(
-                result.get(CrossValidationTimeSeriesQualityReport.lbl_data),
-                pd.DataFrame,
-            )
-        )
+        self.assertTrue(isinstance(result.get(CrossValidationTimeSeriesQualityReport.lbl_data), pd.DataFrame))
 
     def test_create_quality_report_data_format(self):
         quality_report = CrossValidationTimeSeriesQualityReport(self.model, self.splitter)
@@ -181,11 +156,7 @@ class Test2DQualityReport(unittest.TestCase):
         self.assertIsInstance(metrics, pd.DataFrame)
         self.assertEqual(
             set(metrics.columns),
-            {
-                quality_report.lbl_metrics,
-                quality_report.lbl_metric_value,
-                quality_report.lbl_horizon,
-            },
+            {quality_report.lbl_metrics, quality_report.lbl_metric_value, quality_report.lbl_horizon},
         )
         pd.testing.assert_frame_equal(metrics, result.get(quality_report.lbl_metrics))
 
