@@ -3,6 +3,7 @@ from pathlib import Path
 
 import pandas as pd
 from numpy.random import randint
+from parameterized import parameterized
 
 from model_quality_report.splitters.temporal.cross_validation.by_frequency import ByFrequency
 
@@ -20,6 +21,21 @@ class TestByFrequency(unittest.TestCase):
         self.X = test_data.assign(**{"exog": lambda x: randint(100, size=test_data.shape[0])}).drop(columns=["value"])
         self.y = test_data.set_index("date")["value"]
 
+    @parameterized.expand([(0,), (1,), (2,)])
+    def test_correct_number_of_splits_with_end_date(self, weeks_back: int):
+        start_split_date = pd.Timestamp("2017-01-01")
+        frequency = "W-FRI"
+        splitter = ByFrequency(
+            start_split_date=start_split_date,
+            end_split_date=self.X["date"].max() - pd.offsets.Week(weeks_back),
+            frequency=frequency,
+            date_column_name="date",
+        )
+
+        splits = list(splitter.split(self.X, self.y))
+
+        self.assertEqual(len(splits), 47 - weeks_back)
+
     def test_correct_number_of_splits(self):
         start_split_date = pd.Timestamp("2017-01-01")
         frequency = "W-FRI"
@@ -29,7 +45,7 @@ class TestByFrequency(unittest.TestCase):
             date_column_name="date",
         )
 
-        splits = splitter.split(self.X, self.y)
+        splits = list(splitter.split(self.X, self.y))
 
         self.assertEqual(len(splits), 47)
 
@@ -59,7 +75,7 @@ class TestByFrequency(unittest.TestCase):
             date_column_name="date",
         )
 
-        splits = splitter.split(self.X, self.y)
+        splits = list(splitter.split(self.X, self.y))
 
         for split, split_next in zip(splits[:-1], splits[1:]):
             X_train, _, y_train, _ = split
@@ -81,7 +97,7 @@ class TestByFrequency(unittest.TestCase):
         self.assertTrue(len(errors) > 0)
         self.assertTrue("DatetimeIndex" in errors[0])
 
-    def test_returns_error_if_split_date_too_large(self):
+    def test_returns_error_if_start_split_date_too_large(self):
         start_split_date = pd.Timestamp("2100-01-01")
         frequency = "W-FRI"
         splitter = ByFrequency(
@@ -95,7 +111,7 @@ class TestByFrequency(unittest.TestCase):
         self.assertTrue(len(errors) > 0)
         self.assertTrue(str(start_split_date) in errors[0])
 
-    def test_returns_error_if_split_date_too_small(self):
+    def test_returns_error_if_start_split_date_too_small(self):
         start_split_date = pd.Timestamp("1900-01-01")
         frequency = "W-FRI"
         splitter = ByFrequency(
@@ -109,6 +125,56 @@ class TestByFrequency(unittest.TestCase):
         self.assertTrue(len(errors) > 0)
         self.assertTrue(str(start_split_date) in errors[0])
 
+    def test_returns_error_if_end_split_date_too_large(self):
+        start_split_date = pd.Timestamp("2017-01-01")
+        end_split_date = self.X["date"].max() + pd.offsets.Week(1)
+        frequency = "W-FRI"
+        splitter = ByFrequency(
+            start_split_date=start_split_date,
+            end_split_date=end_split_date,
+            frequency=frequency,
+            date_column_name="date",
+        )
+
+        errors = splitter.validate_parameters(self.X, self.y)
+
+        self.assertTrue(len(errors) > 0)
+        self.assertTrue(str(end_split_date) in errors[0])
+
+    def test_returns_error_if_end_split_date_too_small(self):
+        start_split_date = pd.Timestamp("2017-01-01")
+        end_split_date = self.X["date"].min() - pd.offsets.Week(1)
+        frequency = "W-FRI"
+        splitter = ByFrequency(
+            start_split_date=start_split_date,
+            end_split_date=end_split_date,
+            frequency=frequency,
+            date_column_name="date",
+        )
+
+        errors = splitter.validate_parameters(self.X, self.y)
+
+        self.assertTrue(len(errors) > 0)
+        self.assertTrue(str(end_split_date) in errors[0])
+
+    @parameterized.expand([(0,), (1,), (2,)])
+    def test_returns_error_if_start_split_larger_than_end_split_date(self, weeks_back: int):
+        start_split_date = pd.Timestamp("2017-01-01")
+        end_split_date = start_split_date - pd.offsets.Week(weeks_back)
+        frequency = "W-FRI"
+        splitter = ByFrequency(
+            start_split_date=start_split_date,
+            end_split_date=end_split_date,
+            frequency=frequency,
+            date_column_name="date",
+        )
+
+        errors = splitter.validate_parameters(self.X, self.y)
+
+        self.assertTrue(len(errors) > 0)
+        self.assertTrue(str(start_split_date) in errors[0])
+        self.assertTrue(str(end_split_date) in errors[0])
+
     def test_returns_error_if_wrong_frequency_is_provided(self):
         start_split_date = pd.Timestamp("2017-01-01")
         frequency = "wrong_freq"
@@ -121,7 +187,7 @@ class TestByFrequency(unittest.TestCase):
         errors = splitter.validate_parameters(self.X, self.y)
 
         self.assertTrue(len(errors) > 0)
-        self.assertTrue("wrong_freq" in errors[0])
+        self.assertTrue("wrong_freq" in " ".join(errors))
 
     def test_returns_error_if_wrong_date_col_is_provided(self):
         start_split_date = pd.Timestamp("2017-01-01")
@@ -137,11 +203,14 @@ class TestByFrequency(unittest.TestCase):
         self.assertTrue(len(errors) > 0)
         self.assertTrue("exog" in errors[0])
 
-    def test_parameters_can_be_accessed_by_get_parameters(self):
+    @parameterized.expand([(0,), (1,), (2,)])
+    def test_parameters_can_be_accessed_by_get_parameters(self, weeks_back: int):
         start_split_date = pd.Timestamp("2017-01-01")
+        end_split_date = pd.Timestamp("2017-01-01") - pd.offsets.Week(weeks_back)
         frequency = "W-FRI"
         splitter = ByFrequency(
             start_split_date=start_split_date,
+            end_split_date=end_split_date,
             frequency=frequency,
             date_column_name="date",
         )
@@ -152,6 +221,7 @@ class TestByFrequency(unittest.TestCase):
         self.assertDictEqual(
             {
                 ByFrequency.lbl_start_split_date: start_split_date,
+                ByFrequency.lbl_end_split_date: end_split_date,
                 ByFrequency.lbl_frequency: frequency,
                 ByFrequency.lbl_date_column_name: "date",
             },
